@@ -54,7 +54,7 @@ impl Default for Modifier {
 
 impl<DSP> Cmd<DSP>
 where
-    DSP: Clone + 'static,
+    DSP: 'static,
 {
     /// creates a new Cmd from a function
     pub fn new<F>(f: F) -> Self
@@ -68,12 +68,17 @@ where
     }
 
     /// creates a unified Cmd which batches all the other Cmds in one.
-    pub fn batch(cmds: Vec<Self>) -> Self {
-        let should_update_view =
-            cmds.iter().any(|c| c.modifier.should_update_view);
-        let log_measurements = cmds.iter().any(|c| c.modifier.log_measurements);
+    pub fn batch(cmds: impl IntoIterator<Item = Self>) -> Self {
         let mut commands = vec![];
+        let mut should_update_view = false;
+        let mut log_measurements = false;
         for cmd in cmds {
+            if cmd.modifier.should_update_view {
+                should_update_view = true;
+            }
+            if cmd.modifier.log_measurements {
+                log_measurements = true;
+            }
             commands.extend(cmd.commands);
         }
         Self {
@@ -87,12 +92,14 @@ where
     }
 
     /// Append more cmd into this cmd and return self
-    pub fn append(mut self, cmds: Vec<Self>) -> Self {
-        self.modifier.should_update_view =
-            cmds.iter().any(|c| c.modifier.should_update_view);
-        self.modifier.log_measurements =
-            cmds.iter().any(|c| c.modifier.log_measurements);
+    pub fn append(mut self, cmds: impl IntoIterator<Item = Self>) -> Self {
         for cmd in cmds {
+            if cmd.modifier.should_update_view {
+                self.modifier.should_update_view = true;
+            }
+            if cmd.modifier.log_measurements {
+                self.modifier.log_measurements = true;
+            }
             self.commands.extend(cmd.commands);
         }
         self
@@ -106,14 +113,6 @@ where
         }
     }
 
-    /// Executes the Cmd
-    pub fn emit(self, program: &DSP) {
-        for cb in self.commands {
-            let program_clone = program.clone();
-            cb.emit(program_clone);
-        }
-    }
-
     /// Modify the Cmd such that whether or not it will update the view set by `should_update_view`
     /// when the cmd is executed in the program
     pub fn should_update_view(mut self, should_update_view: bool) -> Self {
@@ -142,6 +141,19 @@ where
     }
 }
 
+impl<DSP> Cmd<DSP>
+where
+    DSP: Clone + 'static,
+{
+    /// Executes the Cmd
+    pub fn emit(self, program: &DSP) {
+        for cb in self.commands {
+            let program_clone = program.clone();
+            cb.emit(program_clone);
+        }
+    }
+}
+
 impl<DSP> Cmd<DSP> {
     /// batch dispatch this msg on the next update loop
     pub fn batch_msg<MSG>(msg_list: Vec<MSG>) -> Self
